@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AdvancedMailServer.py 10084 2017-07-04 08:38:08Z David $
+# $Id: AdvancedMailServer.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2014 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: David $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10084 $
+# $Revision: 10797 $
 
 from datetime import datetime, timedelta
 
@@ -23,7 +23,7 @@ from Iuppiter.schedule import Scheduler
 from Iuppiter.dispatch import WorkRequest, ThreadPool
 from Iuppiter.Logging import createLogger
 
-from Theophrastus.models import Newsletter, ContactMailingStatus
+from emencia.django.newsletter.models import Newsletter, ContactMailingStatus
 from Theophrastus.cloud.Mailer import CloudMailer
 from Theophrastus.cloud.service import CloudService
 
