@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 10797 2018-03-01 02:31:02Z David $
+# $Id: models.py 10827 2018-03-11 15:11:03Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,11 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
-# $Revision: 10797 $
+# $Date: 2018-03-11 23:11:03 +0800 (Sun, 11 Mar 2018) $
+# $Revision: 10827 $
 
 from django.db import models
+from django.utils.translation import ugettext_lazy as _
 
 from Iuppiter.Model import BaseModelMixin
 
@@ -40,3 +41,10 @@ class NewsletterInformation(models.Model, BaseModelMixin):
 
     sync = models.BooleanField(default=True)
 
+class ErrorMessage(models.Model):
+
+    message =  models.CharField(max_length=2048, blank=True, null=True)
+
+    newsletter = models.ForeignKey(Newsletter, verbose_name=_('newsletter'))
+
+    contact = models.ForeignKey(Contact, verbose_name=_('contact'))
