@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10797 2018-03-01 02:31:02Z David $
+# $Id: views.py 10827 2018-03-11 15:11:03Z David $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
-# $Revision: 10797 $
+# $Date: 2018-03-11 23:11:03 +0800 (Sun, 11 Mar 2018) $
+# $Revision: 10827 $
 
 import re
 import time
@@ -21,11 +21,17 @@ import json
 
 from urlparse import urljoin
 
+from Iuppiter.dispatch import ThreadPool
+from Iuppiter.extension.views import jsonpCallback
+from Iuppiter.Logging import createLogger
+
 from django.contrib.sites.models import Site
 from django.core.urlresolvers import reverse
 from django.shortcuts import HttpResponse
 from django.utils.translation import ugettext as _
 from django.core.cache import cache
+from django.shortcuts import render_to_response, get_object_or_404
+from django.template import RequestContext
 
 from Iuppiter.extension.views import jsonpCallback
 from Iuppiter.Encoding import _unicode
@@ -33,10 +39,13 @@ from Iuppiter.Logging import createDebugLogger
 
 from django.conf import settings
 
-from emencia.django.newsletter.models import ContactMailingStatus, Contact
+from emencia.django.newsletter.models import ContactMailingStatus, Contact, \
+                                             Newsletter
 
 from Theophrastus.cloud.service import CloudService
+from Theophrastus.cloud.models import ErrorMessage
 from Theophrastus.cloud.Amazon import SES, SNS
+from Theophrastus.cloud.Mailer import CloudMailer
 
 cloudSrv = CloudService.getInstance()
 
@@ -501,7 +510,7 @@ def handleSNS(request):
                 errorCodeList = ['450', '550', '553']
                 if any(x in smtpResponse for x in errorCodeList):
                     amazonLogger.info("Got delivery error, need record...")
-                    recordRejectedStatus(messageId, destination)
+                    recordRejectedStatus(messageId, destination, messageStr)
 
 
         elif topicType == 'UnsubscribeConfirmation':
@@ -691,3 +700,107 @@ def setNotificationTopic(request):
         return _checkResult
     else:
         return doSetNotificationTopic(email)
+
+def resendErrorContact(request, newsletterId):
+    """
+    Resend newsletter to the contacts which has error when
+    sending mail previously.
+
+    @param request Request instance.
+    """
+    SENDBOX_THREAD_POOL_COUNT = settings.SENDBOX_THREAD_POOL_COUNT
+    ENABLE_FAKE_MAIL = settings.ENABLE_FAKE_MAIL
+    ENABLE_FAKE_SMTP = settings.ENABLE_FAKE_SMTP
+    LOG_LEVEL = settings.LOG_LEVEL
+    MAILER_LOGFILE = settings.MAILER_LOGFILE
+
+    sendboxPool = ThreadPool(SENDBOX_THREAD_POOL_COUNT)
+
+    mailerLogger = createLogger(
+                'theophrastusMailer', MAILER_LOGFILE, loggingLevel=LOG_LEVEL)
+
+    newsletter = get_object_or_404(Newsletter, id=newsletterId)
+    opts = Newsletter._meta
+
+    context = {'title': _('Historic of %s') % newsletter.__unicode__(),
+               'original': newsletter,
+               'opts': opts,
+               'object_id': newsletter.pk,
+               'app_label': opts.app_label}
+
+    # TODO: set --> distinct()
+    sentContactIdList = set(
+        ContactMailingStatus.objects.filter(
+            newsletter_id=newsletter.id, status=ContactMailingStatus.SENT
+        ).values_list('contact_id').distinct())
+
+    contactIdSet = set(
+        ContactMailingStatus.objects.filter(
+            newsletter_id=newsletter.id, 
+            status=ContactMailingStatus.ERROR
+        ).exclude(
+                contact_id__in=sentContactIdList).values_list('contact_id'))
+
+    if contactIdSet:
+        contactIdList = [ele[0] for ele in list(contactIdSet)]
+        contactList = Contact.objects.filter(id__in=contactIdList)
+
+        mailer = CloudMailer(newsletter, pool=sendboxPool,
+                                        fakeMail=ENABLE_FAKE_MAIL,
+                                        fakeSMTP=ENABLE_FAKE_SMTP,
+                                        logger=mailerLogger)
+
+        mailer.useCloud = True if newsletter.server.id == 1 else False
+        mailer.smtp_connect()
+        mailer.attachments = mailer.getAttachments()
+
+        for contact in contactList:
+            mailer.send(contact)
+
+        context['sendConfirm'] = _('Resend error emails finish')
+    else:
+        context['information'] = _('All errors have been resent')
+
+    return render_to_response('NewsletterHistoric.html',
+                              context, context_instance=RequestContext(request))
+
+def viewErrorDetails(request, slug, contactMailingStatusId):
+    """
+    Display the error message of a newsletter contact.
+
+    @param request Request instance.
+    @param slug Newsletter's slug.
+    @param cloudmailinformationId Id of CloudMailInformation.
+    """
+
+    contactMailingStatus = ContactMailingStatus.objects.filter(
+                                id=contactMailingStatusId)[0]
+    opts = Newsletter._meta
+    cloudSrv = CloudService.getInstance()
+    newsletter = get_object_or_404(Newsletter, slug=slug)
+
+    if contactMailingStatus.status == ContactMailingStatus.ERROR:
+        content = ErrorMessage.objects.filter(
+            newsletter=contactMailingStatus.newsletter,
+            contact=contactMailingStatus.contact
+        )[0].message
+    else:
+        content = cloudSrv.getCloudMailInformation(
+            newsletter_id=contactMailingStatus.newsletter.id,
+            contact_id=contactMailingStatus.contact.id,
+            errorOnNotFound=False
+        ).message
+    
+    context = {
+        'title': _('Error of contact: %s') % contactMailingStatus.contact.email,
+        'original': newsletter,
+        'opts': opts,
+        'object_id': newsletter.pk,
+        'app_label': opts.app_label,
+        'content': content
+    }
+    return render_to_response(
+        'NewsletterHistoricErrorDetail.html',
+        context,
+        context_instance=RequestContext(request)
+    )
\ No newline at end of file
