@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10813 2018-03-04 16:53:18Z David $
+# $Id: admin.py 10827 2018-03-11 15:11:03Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-03-05 00:53:18 +0800 (Mon, 05 Mar 2018) $
-# $Revision: 10813 $
+# $Date: 2018-03-11 23:11:03 +0800 (Sun, 11 Mar 2018) $
+# $Revision: 10827 $
 
 from django import forms
 from django.contrib import admin
@@ -135,7 +135,7 @@ class NewsletterExtensionAdmin(NewsletterAdmin):
     list_display = ('title', 'getMailingList', 'getServer', 'status',
                 'formatedSendingDate', 'formatedCreationDate',
                 'formatedModificationDate',
-                'getHistory', 'statistics_link')
+                'historic_link', 'statistics_link')
 
     fieldsets = ((None, {'fields': ('title', 'subject', 
                          'header', 'footer',  
@@ -189,21 +189,10 @@ class NewsletterExtensionAdmin(NewsletterAdmin):
     
             return u"<a href='%s'>%s</a>" % (url, server.name)
 
-    def getHistory(self, obj):
-        if obj:
-            url = reverse(
-                'Theophtastus.newsletter_extension.viewHistoric', 
-                args=(obj.slug,)
-            )
-            
-            return u"<a href='%s'>%s</a>" % (url, _('View historic'), )
-
     getMailingList.short_description = _('mailing list')
     getMailingList.allow_tags = True
     getServer.short_description = _('server')
     getServer.allow_tags = True
-    getHistory.short_description = _('history')
-    getHistory.allow_tags = True
 
     class Media:
         try:
